export declare type Config = {
    rules: {
        [ruleName: string]: string[];
    };
    ignore?: {
        definitions?: string[];
    };
};
/**
 * https://swagger.io/specification/#contactObject
 */
export declare type ContactObject = {
    name?: string;
    url?: string;
    email?: string;
};
/**
 * https://swagger.io/specification/#licenseObject
 */
export declare type LicenceObject = {
    name: string;
    url?: string;
};
/**
 * https://swagger.io/specification/#infoObject
 */
export declare type InfoObject = {
    title: string;
    description?: string;
    termsOfService?: string;
    contact?: ContactObject;
    licence?: string;
    version: string;
};
export declare type XMLObject = {
    name?: string;
    namespace?: string;
    prefix?: string;
    attribute?: boolean;
    wrapped?: boolean;
};
export declare type PropBase<A = Object> = {
    title?: string;
    description?: string;
} & A;
declare type StrFormat = 'byte' | 'binary' | 'date' | 'date-time' | 'password';
export declare type PropString = PropBase<{
    type: 'string';
    format?: StrFormat;
    default?: string;
    enum?: string[];
}>;
declare type IntFormat = 'int32' | 'int64';
export declare type PropInteger = PropBase<{
    type: 'integer';
    format?: IntFormat;
    description?: string;
    default?: number;
    minimum?: number;
    maximum?: number;
}>;
declare type NumberFormat = 'float' | 'double';
export declare type PropNumber = PropBase<{
    type: 'number';
    format?: NumberFormat;
    default?: number;
    minimum?: number;
    maximum?: number;
}>;
export declare type PropBoolean = PropBase<{
    type: 'boolean';
    default?: boolean;
}>;
export declare type PropObject = PropBase<{
    type: 'object';
    properties: {
        [k: string]: PropObject | PropString | PropInteger | PropNumber | PropBoolean;
    };
    required: string[];
}>;
export declare type PlainType = 'object' | 'boolean' | 'string' | 'number' | 'integer' | 'array';
export declare type PropArray = PropBase<{
    type: 'array';
    items: {
        $ref: string;
    } | {
        type: PlainType;
    };
}>;
export declare type Property = PropObject | PropString | PropInteger | PropNumber | PropBoolean | PropArray;
export declare type DefinitionObject = {
    title: string;
    description?: string;
    type: PlainType;
    keys: string[];
    readOnly?: boolean;
    required: string[];
    properties: {
        [k: string]: Property;
    };
    xml?: XMLObject;
    externalDocs?: any;
    example?: any;
};
declare type RestSchema = {
    $ref: string;
} | {
    type: 'array';
    items: {
        $ref: string;
    } | {
        type: 'object' | 'boolean' | 'string' | 'number' | 'integer';
    };
};
export declare type PathParameter = {
    name: string;
    in: 'query' | 'path' | 'body';
    description: string;
    required?: boolean;
    allowEmptyValue?: boolean;
} & Property;
export declare type ExternalDocumentationObject = {};
/**
 * https://swagger.io/specification/#parameterObject
 */
export declare type ParameterObject = {
    name: string;
    in: 'query' | 'header' | 'path' | 'cookie';
    description: string;
    required?: boolean;
    deprecated?: boolean;
    allowEmptyValue?: boolean;
};
/**
 * https://swagger.io/specification/#referenceObject
 */
export declare type ReferenceObject = {
    $ref: string;
};
export declare type RequestBodyObject = {};
export declare type SecurityRequirementObject = {};
/**
 * https://swagger.io/specification/#serverVariableObject
 */
export declare type ServerVariableObject = {
    enum?: string[];
    default: string;
    description?: string;
};
/**
 * https://swagger.io/specification/#serverObject
 */
export declare type ServerObject = {
    url: string;
    description: string;
    variables: {
        [n: string]: ServerVariableObject;
    };
};
export declare type CallbackObject = {};
/**
 * https://swagger.io/specification/#operationObject
 */
export declare type OperationObject = {
    tags?: string[];
    summary?: string;
    description?: string;
    externalDocs?: ExternalDocumentationObject;
    operationId: string;
    parameters: (ParameterObject | ReferenceObject)[];
    requestBody?: RequestBodyObject | ReferenceObject;
    responses: {
        [responseCode: string]: {
            description: string;
            schema?: RestSchema;
        };
    };
    callbacks?: {
        [s: string]: CallbackObject | ReferenceObject;
    };
    deprecated?: boolean;
    consumes: string[];
    security: SecurityRequirementObject[];
    servers: ServerObject[];
};
/**
 * https://swagger.io/specification/#pathItemObject
 */
export declare type PathItemObject = {
    $ref?: string;
    summary?: string;
    description?: string;
    get?: OperationObject;
    post?: OperationObject;
    put?: OperationObject;
    delete?: OperationObject;
    options?: OperationObject;
    trace?: OperationObject;
    servers?: ServerObject[];
    parameters?: (ParameterObject | ReferenceObject)[];
};
/**
 * https://swagger.io/specification/#pathsObject
 */
export declare type PathsObject = {
    [m: string]: PathItemObject;
};
export declare type SchemaObject = {};
export declare type ResponseObject = {};
export declare type ExampleObject = {};
export declare type HeaderObject = {};
export declare type SecuritySchemeObject = {};
export declare type LinkObject = {};
/**
 * https://swagger.io/specification/#componentsObject
 */
export declare type ComponentsObject = {
    schemas: {
        [m: string]: SchemaObject | ReferenceObject;
    };
    responses: {
        [m: string]: ResponseObject | ReferenceObject;
    };
    parameters: {
        [m: string]: ParameterObject | ReferenceObject;
    };
    examples: {
        [m: string]: ExampleObject | ReferenceObject;
    };
    requestBodies: {
        [m: string]: RequestBodyObject | ReferenceObject;
    };
    headers: {
        [m: string]: HeaderObject | ReferenceObject;
    };
    securitySchemes: {
        [m: string]: SecuritySchemeObject | ReferenceObject;
    };
    links: {
        [m: string]: LinkObject | ReferenceObject;
    };
    callbacks: {
        [m: string]: CallbackObject | ReferenceObject;
    };
};
/**
 * https://swagger.io/specification/#tagObject
 */
export declare type TagObject = {
    name: string;
    description?: string;
    externalDocs?: ExternalDocumentationObject;
};
/**
 * https://swagger.io/specification/#openapi-object
 */
export declare type OpenAPIObject = {
    /**
     * Semantic version numver
     */
    openapi: string;
    info: InfoObject;
    servers?: ServerObject[];
    paths: PathsObject;
    components?: ComponentsObject;
    security?: SecurityRequirementObject[];
    tags: TagObject[];
    externalDocs?: ExternalDocumentationObject;
    swagger: string;
    host: string;
    basePath: string;
    definitions: {
        [k: string]: Property;
    };
};
export declare type LintError = {
    name: string;
    msg: string;
};
export declare type Rule = {
    name: string;
    check: (a: OpenAPIObject, b: string[], c?: Config) => LintError[];
};
export {};
